You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@openoffice.apache.org by pf...@apache.org on 2014/04/29 21:12:03 UTC

svn commit: r1591060 [15/15] - in /openoffice/trunk/main: helpcontent2/source/text/scalc/01/ helpcontent2/source/text/shared/01/ helpcontent2/source/text/simpress/01/ helpcontent2/source/text/smath/01/ helpcontent2/source/text/swriter/01/ helpcontent2/...

Modified: openoffice/trunk/main/offapi/com/sun/star/util/XCloseListener.idl
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/offapi/com/sun/star/util/XCloseListener.idl?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/offapi/com/sun/star/util/XCloseListener.idl (original)
+++ openoffice/trunk/main/offapi/com/sun/star/util/XCloseListener.idl Tue Apr 29 19:11:53 2014
@@ -55,7 +55,7 @@
 
     <p>
     If an event <method scope="com::sun::star::lang">XEventListener::disposing</method>
-    occured, nobody called <method>XCloseable::close</method> on listened object before.
+    occurred, nobody called <method>XCloseable::close</method> on listened object before.
     Then it's not allowed to break this request - it must be accepted!
     </p>
 
@@ -109,16 +109,16 @@ published interface XCloseListener: com:
             raises( CloseVetoException );
 
 	//-------------------------------------------------------------------------
-    /** is called when the listened object is closed realy
+    /** is called when the listened object is closed really
 
         <p>
-        Now the listened object is closed realy. Listener has to accept that;
+        Now the listened object is closed really. Listener has to accept that;
         should deregister himself and relaese all references to it.
         It's not allowed nor possible to disagree with that by throwing any exception.
         </p>
 
         <p>
-        If the event <member scope="com::sun::star::lang">XEventListener::disposing()</member> occured before
+        If the event <member scope="com::sun::star::lang">XEventListener::disposing()</member> occurred before
         it must be accepted too. There exist no chance for a disagreement any more.
         </p>
 

Modified: openoffice/trunk/main/offapi/com/sun/star/util/XCloseable.idl
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/offapi/com/sun/star/util/XCloseable.idl?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/offapi/com/sun/star/util/XCloseable.idl (original)
+++ openoffice/trunk/main/offapi/com/sun/star/util/XCloseable.idl Tue Apr 29 19:11:53 2014
@@ -46,9 +46,9 @@ module com {  module sun {  module star 
         <li>closed   (if it supports <member>XCloseable::close()</member>)</li>
     </ul>
     First version gives the object no chance to disagree with that (e.g. if a
-    process is still running and can't be cancelled realy). Last version
+    process is still running and can't be really cancelled). Last version
     provides this possibility, but can't guarantee real termination of called object.
-    It depends from the environment of an object, if one or both mechanism are neccessary.
+    It depends from the environment of an object, if one or both mechanism are necessary.
     </p>
 
     <p>
@@ -70,8 +70,8 @@ published interface XCloseable: XCloseBr
     /** try to close the object
 
         <p>
-        Must definitly be called before <member scope="com::sun::star::lang">XComponent::dispose()</member>.
-        But nobody can guarentee real closing of called object - because it can disagree with that if any
+        Must definitely be called before <member scope="com::sun::star::lang">XComponent::dispose()</member>.
+        But nobody can guarantee real closing of called object - because it can disagree with that if any
         still running processes can't be cancelled yet. It's not allowed to block this call till internal
         operations will be finished here. They must be cancelled or call must return imediatly by throwing
         the <type>CloseVetoException</type>.  Otherwise (if nothing exist to disagree) it must return normaly.
@@ -106,11 +106,11 @@ published interface XCloseable: XCloseBr
         </p>
 
         @param DeliverOwnership
-                <TRUE/> delegates the ownership of ths closing object to any one which throw the CloseVetoException.
+                <TRUE/> delegates the ownership of this closing object to any one which throw the CloseVetoException.
                 This new owner has to close the closing object again if his still running processes will be finished.
                 <br>
                 <FALSE/> let the ownership at the original one which called the close() method. He must react for possible
-                CloseVetoExceptions and try it again at a later time. This can be usefull for a generic UI handling.
+                CloseVetoExceptions and try it again at a later time. This can be useful for a generic UI handling.
 
         @throws CloseVetoException
             indicates that the closing object himself or any of his currently registered listener disagree with this close() request.

Modified: openoffice/trunk/main/offapi/com/sun/star/util/XSortable.idl
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/offapi/com/sun/star/util/XSortable.idl?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/offapi/com/sun/star/util/XSortable.idl (original)
+++ openoffice/trunk/main/offapi/com/sun/star/util/XSortable.idl Tue Apr 29 19:11:53 2014
@@ -40,7 +40,7 @@ module com {  module sun {  module star 
  
 /** makes it possible to sort the contents of this object.
 
-    <p>The available properties describing the sort criterias are 
+    <p>The available properties describing the sort criteria are 
     defined in the sort descriptor implemented by the object that
     implements this interface.</p>
 

Modified: openoffice/trunk/main/offapi/com/sun/star/util/XStringSubstitution.idl
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/offapi/com/sun/star/util/XStringSubstitution.idl?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/offapi/com/sun/star/util/XStringSubstitution.idl (original)
+++ openoffice/trunk/main/offapi/com/sun/star/util/XStringSubstitution.idl Tue Apr 29 19:11:53 2014
@@ -67,7 +67,7 @@ published interface XStringSubstitution 
             A string containing variables that should be substituted.
 
 		@param bSubstRequired
-			Specifies if a successfull substitution is required. The 
+			Specifies if a successful substitution is required. The 
 			function throws a <type scope="com::sun::star::container">NoSuchElementException</type>
 			if it finds a variable that is unknown. In this case it is possible 
 			that the returned string would not be what the caller expected!
@@ -106,7 +106,7 @@ published interface XStringSubstitution 
 	  
 		<p>
 		The method iterates through it's internal variable list and tries to 
-		find the given variable. If the variable is unkown a 
+		find the given variable. If the variable is unknown a 
 		<type scope="com::sun::star::container">NoSuchElementException</type>
 		is thrown.
 		</p>

Modified: openoffice/trunk/main/offapi/com/sun/star/util/XTextSearch.idl
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/offapi/com/sun/star/util/XTextSearch.idl?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/offapi/com/sun/star/util/XTextSearch.idl (original)
+++ openoffice/trunk/main/offapi/com/sun/star/util/XTextSearch.idl Tue Apr 29 19:11:53 2014
@@ -113,7 +113,7 @@ published constants SearchFlags
     /** Flag for "Weighted Levenshtein Distance" search / Relaxed 
         checking of limit, split weigh pools.
 
-        <p> If not specified (<b>strict</b>), the search is sucessful if 
+        <p> If not specified (<b>strict</b>), the search is successful if 
         the WLD is within a calculated limit where each insertion, 
         deletion and replacement adds a weight to a common pool of 
         weights. This is the mathematically correct WLD. </p>

Modified: openoffice/trunk/main/offapi/com/sun/star/util/XURLTransformer.idl
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/offapi/com/sun/star/util/XURLTransformer.idl?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/offapi/com/sun/star/util/XURLTransformer.idl (original)
+++ openoffice/trunk/main/offapi/com/sun/star/util/XURLTransformer.idl Tue Apr 29 19:11:53 2014
@@ -99,7 +99,7 @@ published interface XURLTransformer: com
         stores it into <member>URL::Complete</member>
 
         @param aURL
-                the URL which contains alls neccessary information in a structured form. The 
+                the URL which contains alls necessary information in a structured form. The 
                 member <member>URL::Complete</member> contains the URL in string notation after 
 				the operation finished successfully. Otherwise the content of <member>URL::complete</member>
 				is not defined.
@@ -113,7 +113,7 @@ published interface XURLTransformer: com
     /** returns a representation of the URL for UI purposes only
 
         <p>
-        Sometimes it can be usefull to show an URL on an user interface
+        Sometimes it can be useful to show an URL on an user interface
         in a more "human readable" form. Such URL can't be used on any API
         call, but make it easier for the user to understand it.
         </p>

Modified: openoffice/trunk/main/offapi/com/sun/star/xforms/XModel.idl
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/offapi/com/sun/star/xforms/XModel.idl?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/offapi/com/sun/star/xforms/XModel.idl (original)
+++ openoffice/trunk/main/offapi/com/sun/star/xforms/XModel.idl Tue Apr 29 19:11:53 2014
@@ -103,7 +103,7 @@ interface XModel
             consistency criteria for the model data is not fulfilled.
 
         @throws com::sun::star::lang::WrappedTargetException
-            when another error occured during the submission. The
+            when another error occurred during the submission. The
             <member scope="com::sun::star::lang">WrappedTargetException::TargetException</member> describes
             this error then.
     */
@@ -127,7 +127,7 @@ interface XModel
             consistency criteria for the model data is not fulfilled.
 
         @throws com::sun::star::lang::WrappedTargetException
-            when another error occured during the submission. The
+            when another error occurred during the submission. The
             <member scope="com::sun::star::lang">WrappedTargetException::TargetException</member> describes
             this error then.
     */

Modified: openoffice/trunk/main/offapi/com/sun/star/xml/crypto/sax/XMissionTaker.idl
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/offapi/com/sun/star/xml/crypto/sax/XMissionTaker.idl?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/offapi/com/sun/star/xml/crypto/sax/XMissionTaker.idl (original)
+++ openoffice/trunk/main/offapi/com/sun/star/xml/crypto/sax/XMissionTaker.idl Tue Apr 29 19:11:53 2014
@@ -36,7 +36,7 @@ module com { module sun { module star { 
 /**
  * Interface of Mission Taker.
  * <p>
- * This interface is used to controll a mission.
+ * This interface is used to control a mission.
  */
 interface XMissionTaker : com::sun::star::uno::XInterface
 {

Modified: openoffice/trunk/main/offapi/com/sun/star/xml/crypto/sax/XSAXEventKeeper.idl
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/offapi/com/sun/star/xml/crypto/sax/XSAXEventKeeper.idl?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/offapi/com/sun/star/xml/crypto/sax/XSAXEventKeeper.idl (original)
+++ openoffice/trunk/main/offapi/com/sun/star/xml/crypto/sax/XSAXEventKeeper.idl Tue Apr 29 19:11:53 2014
@@ -122,7 +122,7 @@ interface XSAXEventKeeper : com::sun::st
 	/**
 	 * Prints information about all bufferred elements.
 	 *
-	 * @return   a tree-style string including all buffer informtion
+	 * @return   a tree-style string including all buffer information
 	 */
 	string printBufferNodeTree();
 	

Modified: openoffice/trunk/main/offapi/com/sun/star/xml/dom/events/EventType.idl
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/offapi/com/sun/star/xml/dom/events/EventType.idl?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/offapi/com/sun/star/xml/dom/events/EventType.idl (original)
+++ openoffice/trunk/main/offapi/com/sun/star/xml/dom/events/EventType.idl Tue Apr 29 19:11:53 2014
@@ -111,7 +111,7 @@ enum EventType
 
     DOMSubtreeModified,
     /*
-    This is a general event for notification of all changes to the document. It can be used instead of the more specific events listed below. It may be fired after a single modification to the document or, at the implementation's discretion, after multiple changes have occurred. The latter use should generally be used to accomodate multiple changes which occur either simultaneously or in rapid succession. The target of this event is the lowest common parent of the changes which have taken place. This event is dispatched after any other events caused by the mutation have fired.
+    This is a general event for notification of all changes to the document. It can be used instead of the more specific events listed below. It may be fired after a single modification to the document or, at the implementation's discretion, after multiple changes have occurred. The latter use should generally be used to accommodate multiple changes which occur either simultaneously or in rapid succession. The target of this event is the lowest common parent of the changes which have taken place. This event is dispatched after any other events caused by the mutation have fired.
     * Bubbles: Yes
     * Cancelable: No
     * Context Info: None

Modified: openoffice/trunk/main/offapi/com/sun/star/xml/input/XElement.idl
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/offapi/com/sun/star/xml/input/XElement.idl?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/offapi/com/sun/star/xml/input/XElement.idl (original)
+++ openoffice/trunk/main/offapi/com/sun/star/xml/input/XElement.idl Tue Apr 29 19:11:53 2014
@@ -63,7 +63,7 @@ interface XElement : com::sun::star::uno
     */
     XAttributes getAttributes();
     
-    /** Called upon each occuring child element.
+    /** Called upon each occurring child element.
         
         @param uid
                namespace uid of element

Modified: openoffice/trunk/main/offapi/com/sun/star/xml/sax/XExtendedDocumentHandler.idl
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/offapi/com/sun/star/xml/sax/XExtendedDocumentHandler.idl?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/offapi/com/sun/star/xml/sax/XExtendedDocumentHandler.idl (original)
+++ openoffice/trunk/main/offapi/com/sun/star/xml/sax/XExtendedDocumentHandler.idl Tue Apr 29 19:11:53 2014
@@ -49,7 +49,7 @@ published interface XExtendedDocumentHan
 	/** receives notification about the start of a CDATA section in the 
 		XML-source.
 		
-		<p>Any string comming in via character handler may include chars, 
+		<p>Any string coming in via character handler may include chars, 
 		that would otherwise be interpreted as markup. </p>
 	 */
 	void startCDATA() 

Modified: openoffice/trunk/main/offapi/com/sun/star/xml/sax/XFastAttributeList.idl
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/offapi/com/sun/star/xml/sax/XFastAttributeList.idl?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/offapi/com/sun/star/xml/sax/XFastAttributeList.idl (original)
+++ openoffice/trunk/main/offapi/com/sun/star/xml/sax/XFastAttributeList.idl Tue Apr 29 19:11:53 2014
@@ -47,7 +47,7 @@ module com {  module sun {  module star 
  
 /** a container for the attributes of an xml element. 
 
-	<br>Attributes are seperated into known attributes and unknown attributes.
+	<br>Attributes are separated into known attributes and unknown attributes.
 	<p>Known attributes have a local name that is known to the <type>XFastTokenHandler</token>
 	registered at the <type>XFastParser</type> which created the sax event containing
 	this attributes. If an attribute also has a namespace, that must be registered

Modified: openoffice/trunk/main/offapi/com/sun/star/xml/sax/XFastParser.idl
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/offapi/com/sun/star/xml/sax/XFastParser.idl?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/offapi/com/sun/star/xml/sax/XFastParser.idl (original)
+++ openoffice/trunk/main/offapi/com/sun/star/xml/sax/XFastParser.idl Tue Apr 29 19:11:53 2014
@@ -98,7 +98,7 @@ module com {  module sun {  module star 
 
 	<p>Setting a <type>XFastTokenHandler</type> with <member>setTokenHandler</member>
 	is optional, but without a <type>XFastTokenHandler</type> you will only
-	get unknown sax events. This can be usefull if you are only interested
+	get unknown sax events. This can be useful if you are only interested
 	in the namespace handling and/or the context feature.
 
 	<p>For each element the parser sends a create child element event to the

Modified: openoffice/trunk/main/offapi/com/sun/star/xml/wrapper/XXMLDocumentWrapper.idl
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/offapi/com/sun/star/xml/wrapper/XXMLDocumentWrapper.idl?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/offapi/com/sun/star/xml/wrapper/XXMLDocumentWrapper.idl (original)
+++ openoffice/trunk/main/offapi/com/sun/star/xml/wrapper/XXMLDocumentWrapper.idl Tue Apr 29 19:11:53 2014
@@ -46,7 +46,7 @@ interface XXMLElementWrapper;
  * data structure, this interface provides a common method set which
  * each lauguage have to implement. 
  * <p>
- * In another word, this interface wraps language dependant methods,
+ * In another word, this interface wraps language dependent methods,
  * then other component can manipulate DOM data through UNO methods.
  */
 interface XXMLDocumentWrapper : com::sun::star::uno::XInterface

Modified: openoffice/trunk/main/offapi/com/sun/star/xml/wrapper/XXMLElementWrapper.idl
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/offapi/com/sun/star/xml/wrapper/XXMLElementWrapper.idl?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/offapi/com/sun/star/xml/wrapper/XXMLElementWrapper.idl (original)
+++ openoffice/trunk/main/offapi/com/sun/star/xml/wrapper/XXMLElementWrapper.idl Tue Apr 29 19:11:53 2014
@@ -37,7 +37,7 @@ module com { module sun { module star { 
  * Interface of XML Element Wrapper.
  * <p>
  * This interface is used to wrap a element information, which
- * make it enable to tranfer the element information between
+ * make it enable to transfer the element information between
  * different languages, such as C++/Java.
  */
 interface XXMLElementWrapper : com::sun::star::uno::XInterface

Modified: openoffice/trunk/main/officecfg/registry/data/org/openoffice/Office/Labels.xcu
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/officecfg/registry/data/org/openoffice/Office/Labels.xcu?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/officecfg/registry/data/org/openoffice/Office/Labels.xcu (original)
+++ openoffice/trunk/main/officecfg/registry/data/org/openoffice/Office/Labels.xcu Tue Apr 29 19:11:53 2014
@@ -3908,7 +3908,7 @@
 
 				<prop oor:name="Name">
 
-                    <value>L7651 Mini Adress</value>
+                    <value>L7651 Mini Address</value>
 				</prop>
 				<prop oor:name="Measure">
 

Modified: openoffice/trunk/main/officecfg/registry/data/org/openoffice/Office/UI/GenericCommands.xcu
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/officecfg/registry/data/org/openoffice/Office/UI/GenericCommands.xcu?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/officecfg/registry/data/org/openoffice/Office/UI/GenericCommands.xcu (original)
+++ openoffice/trunk/main/officecfg/registry/data/org/openoffice/Office/UI/GenericCommands.xcu Tue Apr 29 19:11:53 2014
@@ -5153,7 +5153,7 @@
                     <value>9</value>
                 </prop>
             </node>
-            <node oor:name=".uno:Substract" oor:op="replace">
+            <node oor:name=".uno:Subtract" oor:op="replace">
                 <prop oor:name="Label" oor:type="xs:string">
                     <value xml:lang="en-US">~Subtract</value>
                 </prop>

Modified: openoffice/trunk/main/officecfg/registry/schema/org/openoffice/Office/Common.xcs
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/officecfg/registry/schema/org/openoffice/Office/Common.xcs?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/officecfg/registry/schema/org/openoffice/Office/Common.xcs (original)
+++ openoffice/trunk/main/officecfg/registry/schema/org/openoffice/Office/Common.xcs Tue Apr 29 19:11:53 2014
@@ -1023,7 +1023,7 @@
 			<prop oor:name="PaintBuffer" oor:type="xs:boolean">
 				<info>
 					<author>AW</author>
-					<desc>Specifies if the Application Repaint shall use a buffer for Pre-Rendering. If on, screen flicker is greatly reduced and remote display is fast, but a buffer (graphics memory) is needed. If off, screen flicker will occurr and remote display is slow, but no buffer is needed. This is the global switch for the whole office.</desc>
+					<desc>Specifies if the Application Repaint shall use a buffer for Pre-Rendering. If on, screen flicker is greatly reduced and remote display is fast, but a buffer (graphics memory) is needed. If off, screen flicker will occur and remote display is slow, but no buffer is needed. This is the global switch for the whole office.</desc>
 					<label>Application Repaint is allowed to use Pre-Rendering Buffer.</label>
 				</info>
 				<value>true</value>
@@ -4829,7 +4829,7 @@
 						<desc>Contains settings for HTML import.</desc>
 					</info>
 					<prop oor:name="NumbersEnglishUS" oor:type="xs:boolean">
-                        <!-- UIHints: Tools  Options  Load/Save - HTML Compability [Section] Import -->
+                        <!-- UIHints: Tools  Options  Load/Save - HTML Compatibility [Section] Import -->
 						<info>
 							<author>ER</author>
 							<desc>Specifies if numbers should be parsed according to the en-US locale instead of the user's locale.</desc>
@@ -6164,7 +6164,7 @@
                 previews, etc...). EdgeBlending will visualize a one pixel border on the preview object with interpolated
                 colors (default: TopLeft White, BottomRight Black) so that a nice 3D effect is shown. It is a percent
                 value describing how strong the effect shall be. The value 0% switches it off, while the value 100% will
-                cover the preview object's border completely with one pixel. Values in-between vill be alpha-blended with
+                cover the preview object's border completely with one pixel. Values in-between will be alpha-blended with
                 the original preview image.
               </desc>
               <label>Defines the EdgeBlending for Previews in Percent.</label>

Modified: openoffice/trunk/main/officecfg/registry/schema/org/openoffice/Office/Embedding.xcs
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/officecfg/registry/schema/org/openoffice/Office/Embedding.xcs?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/officecfg/registry/schema/org/openoffice/Office/Embedding.xcs (original)
+++ openoffice/trunk/main/officecfg/registry/schema/org/openoffice/Office/Embedding.xcs Tue Apr 29 19:11:53 2014
@@ -130,7 +130,7 @@
 		<group oor:name="MimeTypeClassIDRelations" oor:extensible="true">
 			<info>
 				<author>MAV</author>
-				<desc>Contains convertion table from MimeType to ClassID. MimeType is used as a name for entry.</desc>
+				<desc>Contains conversion table from MimeType to ClassID. MimeType is used as a name for entry.</desc>
 			</info>
 		</group>
 		<group oor:name="UserFactories" oor:extensible="true">

Modified: openoffice/trunk/main/officecfg/registry/schema/org/openoffice/Office/ExtensionDependencies.xcs
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/officecfg/registry/schema/org/openoffice/Office/ExtensionDependencies.xcs?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/officecfg/registry/schema/org/openoffice/Office/ExtensionDependencies.xcs (original)
+++ openoffice/trunk/main/officecfg/registry/schema/org/openoffice/Office/ExtensionDependencies.xcs Tue Apr 29 19:11:53 2014
@@ -22,12 +22,12 @@
 <oor:component-schema oor:name="ExtensionDependencies" oor:package="org.openoffice.Office" xml:lang="en-US" xmlns:oor="http://openoffice.org/2001/registry" xmlns:xs="http://www.w3.org/2001/XMLSchema" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance">
     <info>
 	<author>JSC</author>
-        <desc>Contains a list of extensions with additonal dependencies to overrule missing dependencies in extensions
+        <desc>Contains a list of extensions with additional dependencies to overrule missing dependencies in extensions
               or to control specific extensions in general.</desc>
     </info>
     <templates>
         <group oor:name="Extension">
-            <info><desc>Describes the additonal meta data for an extension whereas the node name have to be the extension identifier.</desc></info>
+            <info><desc>Describes the additional meta data for an extension whereas the node name have to be the extension identifier.</desc></info>
             <prop oor:name="Versions" oor:type="oor:string-list" oor:localized="false">
                 <info><desc>Specifies a list of extension versions for which the extra dependecies should be active.</desc></info>
             </prop>
@@ -35,7 +35,7 @@
                 <info><desc>Specifies a list of platforms for which the extra dependencies mechanism is active.</desc></info>
             </prop>
             <prop oor:name="Dependencies" oor:type="xs:string" oor:localized="false">
-                <info><desc>Specifies a list of additonal dependencies.</desc></info>
+                <info><desc>Specifies a list of additional dependencies.</desc></info>
             </prop>
 	</group>
     </templates>

Modified: openoffice/trunk/main/officecfg/registry/schema/org/openoffice/Office/ExtensionManager.xcs
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/officecfg/registry/schema/org/openoffice/Office/ExtensionManager.xcs?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/officecfg/registry/schema/org/openoffice/Office/ExtensionManager.xcs (original)
+++ openoffice/trunk/main/officecfg/registry/schema/org/openoffice/Office/ExtensionManager.xcs Tue Apr 29 19:11:53 2014
@@ -55,7 +55,7 @@
         </group>
         <group oor:name="ExtensionUpdateData">
             <info>
-                <desc>Contains inforamtion about availabe or ignored updates for extensions."</desc>
+                <desc>Contains information about available or ignored updates for extensions."</desc>
             </info>
             <set oor:name="AvailableUpdates" oor:node-type="UpdateInfo">
                 <info>

Modified: openoffice/trunk/main/officecfg/registry/schema/org/openoffice/Office/Histories.xcs
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/officecfg/registry/schema/org/openoffice/Office/Histories.xcs?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/officecfg/registry/schema/org/openoffice/Office/Histories.xcs (original)
+++ openoffice/trunk/main/officecfg/registry/schema/org/openoffice/Office/Histories.xcs Tue Apr 29 19:11:53 2014
@@ -62,7 +62,7 @@
 			</info>
 			<prop oor:name="HistoryItemRef" oor:type="xs:string">
 				<info>
-					<desc>Reference to an item of the orginal history list.</desc>
+					<desc>Reference to an item of the original history list.</desc>
 				</info>
 			</prop>
         </group>

Modified: openoffice/trunk/main/officecfg/registry/schema/org/openoffice/Office/OOoImprovement/Settings.xcs
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/officecfg/registry/schema/org/openoffice/Office/OOoImprovement/Settings.xcs?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/officecfg/registry/schema/org/openoffice/Office/OOoImprovement/Settings.xcs (original)
+++ openoffice/trunk/main/officecfg/registry/schema/org/openoffice/Office/OOoImprovement/Settings.xcs Tue Apr 29 19:11:53 2014
@@ -58,7 +58,7 @@
       </prop>
       <prop oor:name="HelpUrl" oor:type="xs:string">
         <info>
-          <desc>the url where additional infomation can be found.</desc>
+          <desc>the url where additional information can be found.</desc>
         </info>
         <value>http://wiki.services.openoffice.org/wiki/User_Experience/OpenOffice.org_User_Feedback_Program</value>
       </prop>

Modified: openoffice/trunk/main/officecfg/registry/schema/org/openoffice/Office/OptionsDialog.xcs
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/officecfg/registry/schema/org/openoffice/Office/OptionsDialog.xcs?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/officecfg/registry/schema/org/openoffice/Office/OptionsDialog.xcs (original)
+++ openoffice/trunk/main/officecfg/registry/schema/org/openoffice/Office/OptionsDialog.xcs Tue Apr 29 19:11:53 2014
@@ -81,7 +81,7 @@
       </info>
       <set oor:name="Nodes" oor:node-type="OrderedNode">
 	<info>
-	  <desc>A set member countains a Node (see type Node) which has been 
+	  <desc>A set member contains a Node (see type Node) which has been 
 	    assigned to this Module. Also entities which do not own the Module 
 	    may add members to the set. Please look at the specification for 
 	    applying restrictions
@@ -275,7 +275,7 @@
     
     <set oor:name="Modules" oor:node-type="Module">
       <info>
-	<desc>List of availabe application contexts</desc>
+	<desc>List of available application contexts</desc>
       </info>
     </set>
     <set oor:name="Nodes" oor:node-type="Node">

Modified: openoffice/trunk/main/officecfg/registry/schema/org/openoffice/Office/Paths.xcs
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/officecfg/registry/schema/org/openoffice/Office/Paths.xcs?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/officecfg/registry/schema/org/openoffice/Office/Paths.xcs (original)
+++ openoffice/trunk/main/officecfg/registry/schema/org/openoffice/Office/Paths.xcs Tue Apr 29 19:11:53 2014
@@ -26,7 +26,7 @@
 
 	<info>
         <author>AS</author>
-		<desc>Configuration of layered pathes replacing the old path configuration org.openoffice.Office.Common/Path.</desc>
+		<desc>Configuration of layered paths replacing the old path configuration org.openoffice.Office.Common/Path.</desc>
 	</info>
 
 	<templates>
@@ -48,7 +48,7 @@
                 </info>
             <prop oor:name="IsSinglePath" oor:type="xs:boolean">
 				<info>
-					<desc>Mark a NamedPath as SinglePath (false=MultiPath). Only the property WritePath is used for such single pathes then.</desc>
+					<desc>Mark a NamedPath as SinglePath (false=MultiPath). Only the property WritePath is used for such single paths then.</desc>
 				</info>
                 <value>false</value>
             </prop>

Modified: openoffice/trunk/main/officecfg/registry/schema/org/openoffice/Office/PresenterScreen.xcs
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/officecfg/registry/schema/org/openoffice/Office/PresenterScreen.xcs?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/officecfg/registry/schema/org/openoffice/Office/PresenterScreen.xcs (original)
+++ openoffice/trunk/main/officecfg/registry/schema/org/openoffice/Office/PresenterScreen.xcs Tue Apr 29 19:11:53 2014
@@ -176,7 +176,7 @@
     <group oor:name="ToolBarEntry">
       <info><desc>Describes a ToolBar entry.</desc></info>
       <prop oor:name="Name" oor:type="xs:string">
-        <info><desc>Name of the entry.  May be used to have mode dependant entries.</desc></info>
+        <info><desc>Name of the entry.  May be used to have mode dependent entries.</desc></info>
       </prop>
       <prop oor:name="Type" oor:type="xs:string">
         <info><desc>Type of the entry.  Examples are "Label" and "Button".</desc></info>

Modified: openoffice/trunk/main/officecfg/registry/schema/org/openoffice/Office/TabBrowse.xcs
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/officecfg/registry/schema/org/openoffice/Office/TabBrowse.xcs?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/officecfg/registry/schema/org/openoffice/Office/TabBrowse.xcs (original)
+++ openoffice/trunk/main/officecfg/registry/schema/org/openoffice/Office/TabBrowse.xcs Tue Apr 29 19:11:53 2014
@@ -47,7 +47,7 @@
                 <info>
             		<desc>Because there can exists more then one implementations of such TaskCreatorService,
                           the actual one must be specified with it's UNO implementation name.
-                          Otherwise it's not guaranteed, which implementation is realy used at runtime.</desc>
+                          Otherwise it's not guaranteed, which implementation is really used at runtime.</desc>
             	</info>
             </prop>
         </group>

Modified: openoffice/trunk/main/officecfg/registry/schema/org/openoffice/Office/UI.xcs
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/officecfg/registry/schema/org/openoffice/Office/UI.xcs?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/officecfg/registry/schema/org/openoffice/Office/UI.xcs (original)
+++ openoffice/trunk/main/officecfg/registry/schema/org/openoffice/Office/UI.xcs Tue Apr 29 19:11:53 2014
@@ -655,7 +655,7 @@
 			</info>
 			<prop oor:name="FillAsynchronously" oor:type="xs:boolean">
 				<info>
-					<desc>Specifies whether the dialog should fill its view asynchronously. Asnychronous filling allows the user to cancel blocking operations, which may be usefull for instance for mounted, but dead NFS devices.</desc>
+					<desc>Specifies whether the dialog should fill its view asynchronously. Asnychronous filling allows the user to cancel blocking operations, which may be useful for instance for mounted, but dead NFS devices.</desc>
 				</info>
 				<value>false</value>
 			</prop>

Modified: openoffice/trunk/main/officecfg/registry/schema/org/openoffice/Office/UI/Sidebar.xcs
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/officecfg/registry/schema/org/openoffice/Office/UI/Sidebar.xcs?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/officecfg/registry/schema/org/openoffice/Office/UI/Sidebar.xcs (original)
+++ openoffice/trunk/main/officecfg/registry/schema/org/openoffice/Office/UI/Sidebar.xcs Tue Apr 29 19:11:53 2014
@@ -147,7 +147,7 @@
       </prop>
       <prop oor:name="TitleBarIsOptional" oor:type="xs:boolean">
         <info>
-          <desc>When true then the title bar can be ommitted when the panel is the only panel in a deck.</desc>
+          <desc>When true, the title bar can be omitted when the panel is the only panel in a deck.</desc>
         </info>
         <value>false</value>
       </prop>

Modified: openoffice/trunk/main/officecfg/registry/schema/org/openoffice/Office/UI/WindowState.xcs
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/officecfg/registry/schema/org/openoffice/Office/UI/WindowState.xcs?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/officecfg/registry/schema/org/openoffice/Office/UI/WindowState.xcs (original)
+++ openoffice/trunk/main/officecfg/registry/schema/org/openoffice/Office/UI/WindowState.xcs Tue Apr 29 19:11:53 2014
@@ -125,7 +125,7 @@
             </prop>
             <prop oor:name="SoftClose" oor:type="xs:boolean">
                 <info>
-                    <desc>Specifies that a user interface element shouldn't be closed forever. This is usefull for context sensitive ui elements which must be visible whenever their context is active. This property is only used by toolbars or floating window user interface elements.</desc>
+                    <desc>Specifies that a user interface element shouldn't be closed forever. This is useful for context sensitive ui elements which must be visible whenever their context is active. This property is only used by toolbars or floating window user interface elements.</desc>
                 </info>
                 <value>false</value>
             </prop>

Modified: openoffice/trunk/main/officecfg/registry/schema/org/openoffice/Office/WebWizard.xcs
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/officecfg/registry/schema/org/openoffice/Office/WebWizard.xcs?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/officecfg/registry/schema/org/openoffice/Office/WebWizard.xcs (original)
+++ openoffice/trunk/main/officecfg/registry/schema/org/openoffice/Office/WebWizard.xcs Tue Apr 29 19:11:53 2014
@@ -478,7 +478,7 @@
 			</prop>
 			<prop oor:name="Filter" oor:type="xs:string">
 				<info>
-					<desc>Semicolon seperated list of file types this filter will show</desc>
+					<desc>Semicolon separated list of file types this filter will show</desc>
 				</info>
 			</prop>
 		</group>

Modified: openoffice/trunk/main/officecfg/registry/schema/org/openoffice/Office/Writer.xcs
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/officecfg/registry/schema/org/openoffice/Office/Writer.xcs?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/officecfg/registry/schema/org/openoffice/Office/Writer.xcs (original)
+++ openoffice/trunk/main/officecfg/registry/schema/org/openoffice/Office/Writer.xcs Tue Apr 29 19:11:53 2014
@@ -4898,14 +4898,14 @@
 				<info>
 					<desc>Contains settings for the media type used for the label.</desc>
 				</info>
-				<prop oor:name="Continous" oor:type="xs:boolean">
+				<prop oor:name="Continuous" oor:type="xs:boolean">
 					<!-- OldPath: Writer/Dialog/Labels/Labels -->
 					<!-- OldLocation: Soffice.cfg -->
 					<!-- UIHints: File  New  Labels  Labels -->
 					<info>
 						<author>OS</author>
 						<desc>Specifies if continuous paper or individual sheets are used.</desc>
-						<label>Continous / Sheet</label>
+						<label>Continuous / Sheet</label>
 					</info>
 					<value>false</value>
 				</prop>
@@ -5085,14 +5085,14 @@
 				<info>
 					<desc>Contains settings for the media type used.</desc>
 				</info>
-				<prop oor:name="Continous" oor:type="xs:boolean">
+				<prop oor:name="Continuous" oor:type="xs:boolean">
 					<!-- OldPath: Writer/Dialog/BusinessCards/Medium -->
 					<!-- OldLocation: Soffice.cfg -->
 					<!-- UIHints: File  New  BusinessCards  Medium -->
 					<info>
 						<author>OS</author>
 						<desc>Specifies if continuous paper or individual sheets are used.</desc>
-						<label>Continous / Sheet</label>
+						<label>Continuous / Sheet</label>
 					</info>
 					<value>false</value>
 				</prop>

Modified: openoffice/trunk/main/officecfg/registry/schema/org/openoffice/Setup.xcs
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/officecfg/registry/schema/org/openoffice/Setup.xcs?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/officecfg/registry/schema/org/openoffice/Setup.xcs (original)
+++ openoffice/trunk/main/officecfg/registry/schema/org/openoffice/Setup.xcs Tue Apr 29 19:11:53 2014
@@ -92,7 +92,7 @@
       </prop>
       <prop oor:name="Priority" oor:type="xs:int">
         <info>
-          <desc>Contains the priority value to specify which migration should be prefered. Higher values are prefered.</desc>
+          <desc>Contains the priority value to specify which migration should be preferred. Higher values are preferred.</desc>
         </info>
         <value/>
       </prop>

Modified: openoffice/trunk/main/officecfg/registry/schema/org/openoffice/TypeDetection/Types.xcs
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/officecfg/registry/schema/org/openoffice/TypeDetection/Types.xcs?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/officecfg/registry/schema/org/openoffice/TypeDetection/Types.xcs (original)
+++ openoffice/trunk/main/officecfg/registry/schema/org/openoffice/TypeDetection/Types.xcs Tue Apr 29 19:11:53 2014
@@ -55,7 +55,7 @@
 				<value>false</value>
 			</prop>
             <prop oor:name="PreferredFilter" oor:type="xs:string">
-                <info><desc>An optimization! Points directly to the preferred filter for this type. No search across all filters is neccessary ...</desc></info>
+                <info><desc>An optimization! Points directly to the preferred filter for this type. No search across all filters is necessary ...</desc></info>
 				<value/>
             </prop>
             <prop oor:name="UIName" oor:localized="true" oor:type="xs:string">

Modified: openoffice/trunk/main/oovbaapi/ooo/vba/XCollectionBase.idl
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/oovbaapi/ooo/vba/XCollectionBase.idl?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/oovbaapi/ooo/vba/XCollectionBase.idl (original)
+++ openoffice/trunk/main/oovbaapi/ooo/vba/XCollectionBase.idl Tue Apr 29 19:11:53 2014
@@ -39,7 +39,7 @@ module ooo { module vba {
 
     The various VBA collection objects expect a specific number of arguments in
     the "Item" method, therefore this method is not part of this base interface
-    but has to be specified seperately in every derived interface.
+    but has to be specified separately in every derived interface.
  */
 interface XCollectionBase
 {

Modified: openoffice/trunk/main/oovbaapi/ooo/vba/msforms/XControl.idl
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/oovbaapi/ooo/vba/msforms/XControl.idl?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/oovbaapi/ooo/vba/msforms/XControl.idl (original)
+++ openoffice/trunk/main/oovbaapi/ooo/vba/msforms/XControl.idl Tue Apr 29 19:11:53 2014
@@ -53,7 +53,7 @@ interface XControl
     //in Dialogs Mso uses pixels
 	[attribute] double Height;
 	[attribute] double Width;
-    //Postion
+    //Position
     [attribute] double  Left;
     [attribute] double  Top;
 	[attribute] string Name;

Modified: openoffice/trunk/main/oox/inc/oox/core/binarycodec.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/oox/inc/oox/core/binarycodec.hxx?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/oox/inc/oox/core/binarycodec.hxx (original)
+++ openoffice/trunk/main/oox/inc/oox/core/binarycodec.hxx Tue Apr 29 19:11:53 2014
@@ -141,7 +141,7 @@ public:
             this size.
 
         @return
-            True = decoding was successful (no error occured).
+            True = decoding was successful (no error occurred).
     */
     bool                decode(
                             sal_uInt8* pnDestData,
@@ -161,7 +161,7 @@ public:
             Number of bytes to be skipped (cipher "seeks" forward).
 
         @return
-            True = skip was successful (no error occured).
+            True = skip was successful (no error occurred).
      */
     bool                skip( sal_Int32 nBytes );
 
@@ -274,7 +274,7 @@ public:
             this size.
 
         @return
-            True = decoding was successful (no error occured).
+            True = decoding was successful (no error occurred).
     */
     bool                decode(
                             sal_uInt8* pnDestData,
@@ -294,7 +294,7 @@ public:
             Number of bytes to be skipped (cipher "seeks" forward).
 
         @return
-            True = skip was successful (no error occured).
+            True = skip was successful (no error occurred).
      */
     bool                skip( sal_Int32 nBytes );
 

Modified: openoffice/trunk/main/oox/inc/oox/drawingml/drawingmltypes.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/oox/inc/oox/drawingml/drawingmltypes.hxx?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/oox/inc/oox/drawingml/drawingmltypes.hxx (original)
+++ openoffice/trunk/main/oox/inc/oox/drawingml/drawingmltypes.hxx Tue Apr 29 19:11:53 2014
@@ -163,7 +163,7 @@ inline sal_Int32 convertEmuToHmm( sal_In
 
 // ============================================================================
 
-/** A structure for a point with 64-bit interger components. */
+/** A structure for a point with 64-bit integer components. */
 struct EmuPoint
 {
     sal_Int64           X;
@@ -175,7 +175,7 @@ struct EmuPoint
 
 // ============================================================================
 
-/** A structure for a size with 64-bit interger components. */
+/** A structure for a size with 64-bit integer components. */
 struct EmuSize
 {
     sal_Int64           Width;
@@ -187,7 +187,7 @@ struct EmuSize
 
 // ============================================================================
 
-/** A structure for a rectangle with 64-bit interger components. */
+/** A structure for a rectangle with 64-bit integer components. */
 struct EmuRectangle : public EmuPoint, public EmuSize
 {
     inline explicit     EmuRectangle() {}

Modified: openoffice/trunk/main/oox/inc/oox/helper/graphichelper.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/oox/inc/oox/helper/graphichelper.hxx?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/oox/inc/oox/helper/graphichelper.hxx (original)
+++ openoffice/trunk/main/oox/inc/oox/helper/graphichelper.hxx Tue Apr 29 19:11:53 2014
@@ -55,7 +55,7 @@ namespace oox {
     persistent graphic objects internally and store them in an internal
     container to prevent their early destruction. This makes it possible to use
     the returned URL of the graphic object in any way (e.g. insert it into a
-    property map) without needing to store it immediatly at an object that
+    property map) without needing to store it immediately at an object that
     resolves the graphic object from the passed URL and thus prevents it from
     being destroyed.
  */

Modified: openoffice/trunk/main/oox/inc/oox/helper/propertyset.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/oox/inc/oox/helper/propertyset.hxx?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/oox/inc/oox/helper/propertyset.hxx (original)
+++ openoffice/trunk/main/oox/inc/oox/helper/propertyset.hxx Tue Apr 29 19:11:53 2014
@@ -95,7 +95,7 @@ public:
                             { return getAnyProperty( nPropId ) >>= orValue; }
 
     /** Gets the specified boolean property from the property set.
-        @return  true = property contains true; false = property contains false or error occured. */
+        @return  true = property contains true; false = property contains false or error occurred. */
     inline bool         getBoolProperty( sal_Int32 nPropId ) const
                             { bool bValue = false; return getProperty( bValue, nPropId ) && bValue; }
 

Modified: openoffice/trunk/main/oox/inc/oox/ole/axbinaryreader.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/oox/inc/oox/ole/axbinaryreader.hxx?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/oox/inc/oox/ole/axbinaryreader.hxx (original)
+++ openoffice/trunk/main/oox/inc/oox/ole/axbinaryreader.hxx Tue Apr 29 19:11:53 2014
@@ -39,7 +39,7 @@ namespace ole {
     seeking operations (tell, seekTo, align) are performed relative to the
     position of the wrapped stream at construction time of this wrapper. It is
     possible to construct this wrapper with an unseekable input stream without
-    loosing any functionality.
+    losing any functionality.
  */
 class AxAlignedInputStream : public BinaryInputStream
 {

Modified: openoffice/trunk/main/oox/inc/oox/vml/vmlinputstream.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/oox/inc/oox/vml/vmlinputstream.hxx?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/oox/inc/oox/vml/vmlinputstream.hxx (original)
+++ openoffice/trunk/main/oox/inc/oox/vml/vmlinputstream.hxx Tue Apr 29 19:11:53 2014
@@ -51,7 +51,7 @@ typedef ::cppu::WeakImplHelper1< ::com::
         not containing the characters '<' and '>' are stripped from the input
         stream.
     
-    2)  Multiple occurences of the same attribute in an element but the last
+    2)  Multiple occurrences of the same attribute in an element but the last
         are removed.
     
     3)  Line breaks represented by a single <br> element (without matching

Modified: openoffice/trunk/main/oox/inc/oox/xls/biffinputstream.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/oox/inc/oox/xls/biffinputstream.hxx?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/oox/inc/oox/xls/defnamesbuffer.hxx (original)
+++ openoffice/trunk/main/oox/inc/oox/xls/defnamesbuffer.hxx Tue Apr 29 19:11:53 2014
@@ -187,7 +187,7 @@ public:
     /** Creates all defined names in the document. */
     void                finalizeImport();
 
-    /** Returns a defined name by zero-based index (order of appearence). */
+    /** Returns a defined name by zero-based index (order of appearance). */
     DefinedNameRef      getByIndex( sal_Int32 nIndex ) const;
     /** Returns a defined name by token index (index in XDefinedNames container). */
     DefinedNameRef      getByTokenIndex( sal_Int32 nIndex ) const;

Modified: openoffice/trunk/main/oox/source/core/filterdetect.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/oox/source/core/filterdetect.cxx?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/oox/source/core/filterdetect.cxx (original)
+++ openoffice/trunk/main/oox/source/core/filterdetect.cxx Tue Apr 29 19:11:53 2014
@@ -627,7 +627,7 @@ OUString SAL_CALL FilterDetect::detect( 
     OUString aFilterName;
     MediaDescriptor aMediaDesc( rMediaDescSeq );
 
-    /*  Check that the user has not choosen to abort detection, e.g. by hitting
+    /*  Check that the user has not chosen to abort detection, e.g. by hitting
         'Cancel' in the password input dialog. This may happen because this
         filter detection is used by different filters. */
     bool bAborted = aMediaDesc.getUnpackedValueOrDefault( MediaDescriptor::PROP_ABORTED(), false );

Modified: openoffice/trunk/main/oox/source/export/preset-definitions-to-shape-types.pl
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/oox/source/export/preset-definitions-to-shape-types.pl?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/oox/source/export/preset-definitions-to-shape-types.pl (original)
+++ openoffice/trunk/main/oox/source/export/preset-definitions-to-shape-types.pl Tue Apr 29 19:11:53 2014
@@ -284,7 +284,7 @@ $path_h = 1;
     201 => 'hostControl', # should not be used
     202 => 'textBox'
 );
-# An error occured, we have to ignore this shape
+# An error occurred, we have to ignore this shape
 sub error( $ )
 {
     my ( $msg ) = @_;

Modified: openoffice/trunk/main/oox/source/vml/vmlinputstream.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/oox/source/vml/vmlinputstream.cxx?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/oox/source/vml/vmlinputstream.cxx (original)
+++ openoffice/trunk/main/oox/source/vml/vmlinputstream.cxx Tue Apr 29 19:11:53 2014
@@ -89,7 +89,7 @@ inline void lclAppendToBuffer( OStringBu
 void lclProcessAttribs( OStringBuffer& rBuffer, const sal_Char* pcBeg, const sal_Char* pcEnd )
 {
     /*  Map attribute names to char-pointer of all attributes. This map is used
-        to find multiple occurences of attributes with the same name. The
+        to find multiple occurrences of attributes with the same name. The
         mapped pointers are used as map key in the next map below. */
     typedef ::std::map< OString, const sal_Char* > AttributeNameMap;
     AttributeNameMap aAttributeNames;
@@ -140,7 +140,7 @@ void lclProcessAttribs( OStringBuffer& r
         }
     }
 
-    // if no error has occured, build the resulting attribute list
+    // if no error has occurred, build the resulting attribute list
     if( bOk )
         for( AttributeDataMap::iterator aIt = aAttributes.begin(), aEnd = aAttributes.end(); aIt != aEnd; ++aIt )
             rBuffer.append( ' ' ).append( aIt->second );

Modified: openoffice/trunk/main/oox/source/xls/formulaparser.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/oox/source/xls/formulaparser.cxx?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/oox/source/xls/formulaparser.cxx (original)
+++ openoffice/trunk/main/oox/source/xls/formulaparser.cxx Tue Apr 29 19:11:53 2014
@@ -367,7 +367,7 @@ const ApiToken* FormulaFinalizer::findPa
 
 void FormulaFinalizer::appendEmptyParameter( const FunctionInfo& rFuncInfo, size_t nParam )
 {
-    // remeber old size of the token array
+    // remember old size of the token array
     size_t nTokenArraySize = maTokens.size();
     
     switch( rFuncInfo.mnBiff12FuncId )

Modified: openoffice/trunk/main/oox/source/xls/sheetdatabuffer.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/oox/source/xls/sheetdatabuffer.cxx?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/oox/source/xls/sheetdatabuffer.cxx (original)
+++ openoffice/trunk/main/oox/source/xls/sheetdatabuffer.cxx Tue Apr 29 19:11:53 2014
@@ -257,7 +257,7 @@ CellBlock* CellBlockBuffer::getCellBlock
         {
             /*  The colspan vector aIt points to is sorted by columns, as well
                 as the cell block map. In the folloing, this vector and the
-                list of cell blocks can be iterated simultanously. */
+                list of cell blocks can be iterated simultaneously. */
             CellBlockMap::iterator aMIt = maCellBlocks.begin();
             const ValueRangeVector& rColRanges = aIt->second;
             for( ValueRangeVector::const_iterator aVIt = rColRanges.begin(), aVEnd = rColRanges.end(); aVIt != aVEnd; ++aVIt, ++aMIt )

Modified: openoffice/trunk/main/package/qa/ofopxmlstorages/Test01.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/package/qa/ofopxmlstorages/Test01.java?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/package/qa/ofopxmlstorages/Test01.java (original)
+++ openoffice/trunk/main/package/qa/ofopxmlstorages/Test01.java Tue Apr 29 19:11:53 2014
@@ -146,7 +146,7 @@ public class Test01 implements StorageTe
 			}
 
 			// copy xTempStorage to xTempFileStorage
-			// xTempFileStorage will be automatically commited
+			// xTempFileStorage will be automatically committed
 			if ( !m_aTestHelper.copyStorage( xTempStorage, xTempFileStorage ) )
 				return false;
 

Modified: openoffice/trunk/main/package/qa/ofopxmlstorages/Test04.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/package/qa/ofopxmlstorages/Test04.java?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/package/qa/ofopxmlstorages/Test04.java (original)
+++ openoffice/trunk/main/package/qa/ofopxmlstorages/Test04.java Tue Apr 29 19:11:53 2014
@@ -170,7 +170,7 @@ public class Test04 implements StorageTe
 			if ( !m_aTestHelper.copyElementTo( xTempStorage, "SubStorage1", xTempFileStorage ) )
 				return false;
 
-			// if storage is not commited before disposing all the changes will be lost
+			// if storage is not committed before disposing all the changes will be lost
 			if ( !m_aTestHelper.commitStorage( xTempSubStorage2 ) )
 				return false;
 

Modified: openoffice/trunk/main/package/qa/ofopxmlstorages/Test07.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/package/qa/ofopxmlstorages/Test07.java?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/package/qa/ofopxmlstorages/TestHelper.java (original)
+++ openoffice/trunk/main/package/qa/ofopxmlstorages/TestHelper.java Tue Apr 29 19:11:53 2014
@@ -1041,7 +1041,7 @@ public class TestHelper  {
 
 	public XStorage cloneStorage( XMultiServiceFactory xMSF, XSingleServiceFactory xFactory, XStorage xStorage )
 	{
-		// create a copy of a last commited version of specified storage
+		// create a copy of a last committed version of specified storage
 		XStorage xResult = null;
 		try
 		{
@@ -1060,7 +1060,7 @@ public class TestHelper  {
 
 	public XStorage cloneSubStorage( XMultiServiceFactory xMSF, XSingleServiceFactory xFactory, XStorage xStorage, String sName )
 	{
-		// create a copy of a last commited version of specified substorage
+		// create a copy of a last committed version of specified substorage
 		XStorage xResult = null;
 		try
 		{

Modified: openoffice/trunk/main/package/qa/storages/RegressionTest_i29169.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/package/qa/storages/RegressionTest_i29169.java?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/package/qa/storages/RegressionTest_i29169.java (original)
+++ openoffice/trunk/main/package/qa/storages/RegressionTest_i29169.java Tue Apr 29 19:11:53 2014
@@ -127,7 +127,7 @@ public class RegressionTest_i29169 imple
 			// commit the storages, and check the renaming in all stages
 			// ================================================
 
-			// rename the storage before it is commited
+			// rename the storage before it is committed
 			if ( !m_aTestHelper.renameElement( xTempSubStorage, "SubSubStorage1", "SubSubStorage2" ) )
 				return false;
 
@@ -139,7 +139,7 @@ public class RegressionTest_i29169 imple
 			if ( !m_aTestHelper.commitStorage( xTempSubSubStorage ) )
 				return false;
 
-			// rename the storage after it is commited
+			// rename the storage after it is committed
 			if ( !m_aTestHelper.renameElement( xTempSubStorage, "SubSubStorage2", "SubSubStorage3" ) )
 				return false;
 
@@ -151,11 +151,11 @@ public class RegressionTest_i29169 imple
 			if ( !m_aTestHelper.commitStorage( xTempSubStorage ) )
 				return false;
 
-			// rename the storage after it`s parent is commited
+			// rename the storage after it's parent is committed
 			if ( !m_aTestHelper.renameElement( xTempSubStorage, "SubSubStorage3", "SubSubStorage4" ) )
 				return false;
 
-			// rename the stream after it`s parent is commited
+			// rename the stream after it's parent is committed
 			if ( !m_aTestHelper.renameElement( xTempSubStorage, "SubStream3", "SubStream4" ) )
 				return false;
 
@@ -167,11 +167,11 @@ public class RegressionTest_i29169 imple
 			if ( !m_aTestHelper.commitStorage( xTempStorage ) )
 				return false;
 
-			// rename the storage after the package is commited
+			// rename the storage after the package is committed
 			if ( !m_aTestHelper.renameElement( xTempSubStorage, "SubSubStorage4", "SubSubStorage5" ) )
 				return false;
 
-			// rename the stream after it`s parent is commited
+			// rename the stream after it's parent is committed
 			if ( !m_aTestHelper.renameElement( xTempSubStorage, "SubStream4", "SubStream5" ) )
 				return false;
 
@@ -252,7 +252,7 @@ public class RegressionTest_i29169 imple
 			// rename the reopened storages and streams
 			// ================================================
 
-			// rename the storage before it is commited
+			// rename the storage before it is committed
 			if ( !m_aTestHelper.renameElement( xTempSubStorage, "SubSubStorage5", "SubSubStorage6" ) )
 				return false;
 
@@ -264,7 +264,7 @@ public class RegressionTest_i29169 imple
 			if ( !m_aTestHelper.commitStorage( xTempSubSubStorage ) )
 				return false;
 
-			// rename the storage after it is commited
+			// rename the storage after it is committed
 			if ( !m_aTestHelper.renameElement( xTempSubStorage, "SubSubStorage6", "SubSubStorage7" ) )
 				return false;
 
@@ -276,11 +276,11 @@ public class RegressionTest_i29169 imple
 			if ( !m_aTestHelper.commitStorage( xTempSubStorage ) )
 				return false;
 
-			// rename the storage after it`s parent is commited
+			// rename the storage after it's parent is committed
 			if ( !m_aTestHelper.renameElement( xTempSubStorage, "SubSubStorage7", "SubSubStorage8" ) )
 				return false;
 
-			// rename the stream after it`s parent is commited
+			// rename the stream after it's parent is committed
 			if ( !m_aTestHelper.renameElement( xTempSubStorage, "SubStream7", "SubStream8" ) )
 				return false;
 
@@ -292,11 +292,11 @@ public class RegressionTest_i29169 imple
 			if ( !m_aTestHelper.commitStorage( xTempStorage ) )
 				return false;
 
-			// rename the storage after the package is commited
+			// rename the storage after the package is committed
 			if ( !m_aTestHelper.renameElement( xTempSubStorage, "SubSubStorage8", "SubSubStorage9" ) )
 				return false;
 
-			// rename the stream after it`s parent is commited
+			// rename the stream after it`s parent is committed
 			if ( !m_aTestHelper.renameElement( xTempSubStorage, "SubStream8", "SubStream9" ) )
 				return false;
 

Modified: openoffice/trunk/main/package/qa/storages/Test01.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/package/qa/storages/Test01.java?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/package/qa/storages/Test01.java (original)
+++ openoffice/trunk/main/package/qa/storages/Test01.java Tue Apr 29 19:11:53 2014
@@ -131,7 +131,7 @@ public class Test01 implements StorageTe
 			}
 
 			// copy xTempStorage to xTempFileStorage
-			// xTempFileStorage will be automatically commited
+			// xTempFileStorage will be automatically committed
 			if ( !m_aTestHelper.copyStorage( xTempStorage, xTempFileStorage ) )
 				return false;
 

Modified: openoffice/trunk/main/package/qa/storages/Test04.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/package/qa/storages/Test04.java?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/package/qa/storages/Test04.java (original)
+++ openoffice/trunk/main/package/qa/storages/Test04.java Tue Apr 29 19:11:53 2014
@@ -155,7 +155,7 @@ public class Test04 implements StorageTe
 			if ( !m_aTestHelper.copyElementTo( xTempStorage, "SubStorage1", xTempFileStorage ) )
 				return false;
 
-			// if storage is not commited before disposing all the changes will be lost
+			// if storage is not committed before disposing all the changes will be lost
 			if ( !m_aTestHelper.commitStorage( xTempSubStorage2 ) )
 				return false;
 

Modified: openoffice/trunk/main/package/qa/storages/Test07.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/package/qa/storages/Test07.java?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/package/qa/storages/Test07.java (original)
+++ openoffice/trunk/main/package/qa/storages/Test07.java Tue Apr 29 19:11:53 2014
@@ -109,7 +109,7 @@ public class Test07 implements StorageTe
 			}
 
 			// copy xTempStorage to xTempFileStorage
-			// xTempFileStorage will be automatically commited
+			// xTempFileStorage will be automatically committed
 			if ( !m_aTestHelper.copyStorage( xTempStorage, xTempFileStorage ) )
 				return false;
 

Modified: openoffice/trunk/main/package/qa/storages/Test08.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/package/qa/storages/Test08.java?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/package/qa/storages/Test08.java (original)
+++ openoffice/trunk/main/package/qa/storages/Test08.java Tue Apr 29 19:11:53 2014
@@ -162,7 +162,7 @@ public class Test08 implements StorageTe
 			}
 
 			// copy xTempStorage to xTempFileStorage
-			// xTempFileStorage will be automatically commited
+			// xTempFileStorage will be automatically committed
 			if ( !m_aTestHelper.copyStorage( xTempStorage, xTempFileStorage ) )
 				return false;
 

Modified: openoffice/trunk/main/package/qa/storages/Test09.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/package/qa/storages/Test09.java?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/package/qa/storages/Test09.java (original)
+++ openoffice/trunk/main/package/qa/storages/Test09.java Tue Apr 29 19:11:53 2014
@@ -99,7 +99,7 @@ public class Test09 implements StorageTe
 			}
 
 			// copy xTempStorage to xTempFileStorage
-			// xTempFileStorage will be automatically commited
+			// xTempFileStorage will be automatically committed
 			if ( !m_aTestHelper.copyStorage( xTempStorage, xTempFileStorage ) )
 				return false;
 

Modified: openoffice/trunk/main/package/qa/storages/Test10.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/package/qa/storages/Test10.java?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/package/qa/storages/Test13.java (original)
+++ openoffice/trunk/main/package/qa/storages/Test13.java Tue Apr 29 19:11:53 2014
@@ -215,7 +215,7 @@ public class Test13 implements StorageTe
 			if ( !m_aTestHelper.checkStreamH( xResultStorage, aBigSubStream1Path, "MediaType3", true, pBigBytes ) )
 				return false;
 
-			// the following stream was not commited last time, so the last change must be lost
+			// the following stream was not committed last time, so the last change must be lost
 			if ( !m_aTestHelper.checkStreamH( xResultStorage, aBigSubStream2Path, "MediaType2", false, pBigBytes ) )
 				return false;
 

Modified: openoffice/trunk/main/package/qa/storages/Test14.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/package/qa/storages/Test14.java?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/package/qa/storages/Test14.java (original)
+++ openoffice/trunk/main/package/qa/storages/Test14.java Tue Apr 29 19:11:53 2014
@@ -188,7 +188,7 @@ public class Test14 implements StorageTe
 			if ( !m_aTestHelper.checkEncrStreamH( xResultStorage, aSubStream1Path, "MediaType3", pBytes2, sPass1 ) )
 				return false;
 
-			// the following stream was not commited last time, so the last change must be lost
+			// the following stream was not committed last time, so the last change must be lost
 			if ( !m_aTestHelper.checkEncrStreamH( xResultStorage, aSubStream2Path, "MediaType2", pBytes2, sPass2 ) )
 				return false;
 

Modified: openoffice/trunk/main/package/qa/storages/Test16.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/package/qa/storages/Test16.java?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/package/qa/storages/Test16.java (original)
+++ openoffice/trunk/main/package/qa/storages/Test16.java Tue Apr 29 19:11:53 2014
@@ -119,7 +119,7 @@ public class Test16 implements StorageTe
 			}
 
 			// copy xTempStorage to xTempFileStorage
-			// xTempFileStorage will be automatically commited
+			// xTempFileStorage will be automatically committed
 			if ( !m_aTestHelper.copyStorage( xTempStorage, xTempFileStorage ) )
 				return false;
 

Modified: openoffice/trunk/main/package/qa/storages/Test18.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/package/qa/storages/Test18.java?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/package/qa/storages/Test18.java (original)
+++ openoffice/trunk/main/package/qa/storages/Test18.java Tue Apr 29 19:11:53 2014
@@ -126,7 +126,7 @@ public class Test18 implements StorageTe
 			}
 
 			// copy xTempStorage to xTempFileStorage
-			// xTempFileStorage will be automatically commited
+			// xTempFileStorage will be automatically committed
 			if ( !m_aTestHelper.copyStorage( xTempStorage, xTempFileStorage ) )
 				return false;
 

Modified: openoffice/trunk/main/package/qa/storages/TestHelper.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/package/qa/storages/TestHelper.java?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/package/qa/storages/TestHelper.java (original)
+++ openoffice/trunk/main/package/qa/storages/TestHelper.java Tue Apr 29 19:11:53 2014
@@ -1599,7 +1599,7 @@ public class TestHelper  {
 
 	public XStorage cloneStorage( XSingleServiceFactory xFactory, XStorage xStorage )
 	{
-		// create a copy of a last commited version of specified storage
+		// create a copy of a last committed version of specified storage
 		XStorage xResult = null;
 		try
 		{
@@ -1619,7 +1619,7 @@ public class TestHelper  {
 
 	public XStorage cloneSubStorage( XSingleServiceFactory xFactory, XStorage xStorage, String sName )
 	{
-		// create a copy of a last commited version of specified substorage
+		// create a copy of a last committed version of specified substorage
 		XStorage xResult = null;
 		try
 		{

Modified: openoffice/trunk/main/package/source/xstor/ohierarchyholder.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/package/source/xstor/ohierarchyholder.cxx?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/package/source/xstor/ohierarchyholder.cxx (original)
+++ openoffice/trunk/main/package/source/xstor/ohierarchyholder.cxx Tue Apr 29 19:11:53 2014
@@ -120,8 +120,8 @@ uno::Reference< embed::XExtendedStorageS
 		uno::Reference< embed::XTransactedObject > xTransact( xResult, uno::UNO_QUERY );
 		if ( xTransact.is() )
 		{
-			// the existance of the transacted object means that the stream is opened for writing also
-			// so the whole chain must be commited
+			// the existence of the transacted object means that the stream is opened for writing also
+			// so the whole chain must be committed
 			uno::Reference< embed::XTransactionBroadcaster > xTrBroadcast( xTransact, uno::UNO_QUERY_THROW );
 			xTrBroadcast->addTransactionListener( static_cast< embed::XTransactionListener* >( this ) );
 		}

Modified: openoffice/trunk/main/package/source/xstor/owriteablestream.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/package/source/xstor/owriteablestream.cxx?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/package/source/xstor/owriteablestream.cxx (original)
+++ openoffice/trunk/main/package/source/xstor/owriteablestream.cxx Tue Apr 29 19:11:53 2014
@@ -1031,7 +1031,7 @@ void OWriteStream_Impl::Revert()
 		}
 		else
 		{
-			// the original stream was aready parsed
+			// the original stream was already parsed
 			if ( !m_bOrigRelInfoBroken )
 				m_nRelInfoStatus = RELINFO_READ;
 			else

Modified: openoffice/trunk/main/package/source/xstor/xstorage.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/package/source/xstor/xstorage.cxx?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/package/source/xstor/xstorage.hxx (original)
+++ openoffice/trunk/main/package/source/xstor/xstorage.hxx Tue Apr 29 19:11:53 2014
@@ -170,7 +170,7 @@ struct OStorage_Impl
 
 	SwitchablePersistenceStream* m_pSwitchStream;
 
-	sal_Int32 m_nStorageType; // the mode in wich the storage is used
+	sal_Int32 m_nStorageType; // the mode in which the storage is used
 
 	// the _rels substorage that is handled in a special way in embed::StorageFormats::OFOPXML
 	SotElement_Impl* m_pRelStorElement; 

Modified: openoffice/trunk/main/package/source/zippackage/ZipPackage.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/package/source/zippackage/ZipPackage.cxx?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/package/source/zippackage/ZipPackage.cxx (original)
+++ openoffice/trunk/main/package/source/zippackage/ZipPackage.cxx Tue Apr 29 19:11:53 2014
@@ -1390,7 +1390,7 @@ uno::Reference< XActiveDataStreamer > Zi
 void SAL_CALL ZipPackage::commitChanges() 
         throw( WrappedTargetException, RuntimeException )
 {
-    // lock the component for the time of commiting
+    // lock the component for the time of committing
     ::osl::MutexGuard aGuard( m_aMutexHolder->GetMutex() );
 
     if ( m_eMode == e_IMode_XInputStream )

Modified: openoffice/trunk/main/package/source/zippackage/zipfileaccess.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/package/source/zippackage/zipfileaccess.cxx?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/package/source/zippackage/zipfileaccess.cxx (original)
+++ openoffice/trunk/main/package/source/zippackage/zipfileaccess.cxx Tue Apr 29 19:11:53 2014
@@ -65,7 +65,7 @@ OZipFileAccess::~OZipFileAccess()
 		if ( !m_bDisposed )
 		{
 			try {
-				m_refCount++; // dispose will use refcounting so the further distruction must be avoided
+				m_refCount++; // dispose will use refcounting so the further destruction must be avoided
 				dispose();
 			} catch( uno::Exception& )
 			{}

Modified: openoffice/trunk/main/padmin/source/padialog.src
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/padmin/source/padialog.src?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/padmin/source/padialog.src (original)
+++ openoffice/trunk/main/padmin/source/padialog.src Tue Apr 29 19:11:53 2014
@@ -353,7 +353,7 @@ String RID_ERR_NOPRINTER
 
 String RID_PA_TXT_TESTPAGE_PRINTED
 {
-	Text [ en-US ] = "The test page was printed succesfully. Please check the result.";
+	Text [ en-US ] = "The test page was printed successfully. Please check the result.";
 };
 
 String RID_ERR_NOWRITE

Modified: openoffice/trunk/main/postprocess/signing/signing.pl
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/postprocess/signing/signing.pl?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/postprocess/signing/signing.pl (original)
+++ openoffice/trunk/main/postprocess/signing/signing.pl Tue Apr 29 19:11:53 2014
@@ -236,7 +236,7 @@ sub execute		#11.07.2007 10:02
 	my $result = "";
 
   	print "$commandline\n" if ($debug);
-  	open(PIPE, "$commandline 2>&1 |") || die "Error: Cant open pipe!\n";
+  	open(PIPE, "$commandline 2>&1 |") || die "Error: Can't open pipe!\n";
   	while ( $result = <PIPE> ) {
   		print LOG "$result" if ($opt_log);        # logging
   		if ( $result =~ /SignTool Error\:/ ) {

Modified: openoffice/trunk/main/pyuno/source/module/pyuno_module.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/pyuno/source/module/pyuno_module.cxx?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/pyuno/source/module/pyuno_module.cxx (original)
+++ openoffice/trunk/main/pyuno/source/module/pyuno_module.cxx Tue Apr 29 19:11:53 2014
@@ -292,7 +292,7 @@ static PyObject *createUnoStructHelper(P
                         OStringBuffer buf;
                         buf.append( "UNO struct " );
                         buf.append( OUStringToOString( typeName, RTL_TEXTENCODING_ASCII_US ) );
-                        buf.append( " is unkown" );
+                        buf.append( " is unknown" );
                         PyErr_SetString (PyExc_RuntimeError, buf.getStr());
                     }
                 }
--- openoffice/trunk/main/oox/inc/oox/xls/biffinputstream.hxx (original)
+++ openoffice/trunk/main/oox/inc/oox/xls/biffinputstream.hxx Tue Apr 29 19:11:53 2014
@@ -152,7 +152,7 @@ public:
     /** Constructs the BIFF record stream using the passed binary stream.
 
         @param rInStream
-            The base input stream. Must be seekable. Will be seeked to its
+            The base input stream. Must be seekable. Will be sought to its
             start position.
 
         @param bContLookup  Automatic CONTINUE lookup on/off.
@@ -348,7 +348,7 @@ public:
 
     // ------------------------------------------------------------------------
 private:
     /** Initializes all members after base stream has been seeked to new record. */
     void                setupRecord();
     /** Restarts the current record from the beginning. */
     void                restartRecord( bool bInvalidateRecSize );
@@ -348,7 +348,7 @@ public:
     // ------------------------------------------------------------------------
 private:
-    /** Initializes all members after base stream has been seeked to new record. */
+    /** Initializes all members after base stream has been sought to new record. */
     void                setupRecord();
     /** Restarts the current record from the beginning. */

Modified: openoffice/trunk/main/oox/inc/oox/xls/defnamesbuffer.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/oox/inc/oox/xls/defnamesbuffer.hxx?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/package/qa/ofopxmlstorages/Test07.java (original)
+++ openoffice/trunk/main/package/qa/ofopxmlstorages/Test07.java Tue Apr 29 19:11:53 2014
@@ -134,7 +134,7 @@ public class Test07 implements StorageTe
 			// check cloning at current state
 			// ==============================
 
 			// the new storage still was not commited so the clone must be empty
 			XStorage xClonedSubStorage = m_aTestHelper.cloneSubStorage( m_xMSF, m_xStorageFactory, xTempStorage, "SubStorage1" );
 
 			if ( xClonedSubStorage == null )
@@ -158,7 +158,7 @@ public class Test07 implements StorageTe
 
 			if ( xClonedNameAccess.hasElements() )
 			{
-				m_aTestHelper.Error( "The new substorage still was not commited so it must be empty!" );
+				m_aTestHelper.Error( "The new substorage still was not committed so it must be empty!" );
 				return false;
 			}
 			
@@ -224,7 +224,7 @@ public class Test07 implements StorageTe
 
 			if ( xCloneOfRootNA.hasElements() )
 			{
-				m_aTestHelper.Error( "The root storage still was not commited so it's clone must be empty!" );
+				m_aTestHelper.Error( "The root storage still was not committed so it's clone must be empty!" );
 				return false;
 			}
 			
@@ -134,7 +134,7 @@ public class Test07 implements StorageTe
 			// ==============================
 
-			// the new storage still was not commited so the clone must be empty
+			// the new storage still was not committed so the clone must be empty
 			XStorage xClonedSubStorage = m_aTestHelper.cloneSubStorage( m_xMSF, m_xStorageFactory, xTempStorage, "SubStorage1" );
 

Modified: openoffice/trunk/main/package/qa/ofopxmlstorages/TestHelper.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/package/qa/ofopxmlstorages/TestHelper.java?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/package/qa/storages/Test10.java (original)
+++ openoffice/trunk/main/package/qa/storages/Test10.java Tue Apr 29 19:11:53 2014
@@ -116,7 +116,7 @@ public class Test10 implements StorageTe
 			// check cloning at current state
 			// ==============================
 
 			// the new storage still was not commited so the clone must be empty
 			XStorage xClonedSubStorage = m_aTestHelper.cloneSubStorage( m_xStorageFactory, xTempStorage, "SubStorage1" );
 
 			if ( xClonedSubStorage == null )
@@ -137,7 +137,7 @@ public class Test10 implements StorageTe
 
 			if ( xClonedNameAccess.hasElements() )
 			{
-				m_aTestHelper.Error( "The new substorage still was not commited so it must be empty!" );
+				m_aTestHelper.Error( "The new substorage still was not committed so it must be empty!" );
 				return false;
 			}
 			
@@ -202,7 +202,7 @@ public class Test10 implements StorageTe
 
 			if ( xCloneOfRootNA.hasElements() )
 			{
-				m_aTestHelper.Error( "The root storage still was not commited so it's clone must be empty!" );
+				m_aTestHelper.Error( "The root storage still was not committed so it's clone must be empty!" );
 				return false;
 			}
 			
@@ -116,7 +116,7 @@ public class Test10 implements StorageTe
 			// ==============================
 
-			// the new storage still was not commited so the clone must be empty
+			// the new storage still was not committed so the clone must be empty
 			XStorage xClonedSubStorage = m_aTestHelper.cloneSubStorage( m_xStorageFactory, xTempStorage, "SubStorage1" );
 

Modified: openoffice/trunk/main/package/qa/storages/Test11.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/package/qa/storages/Test11.java?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/package/qa/storages/Test11.java (original)
+++ openoffice/trunk/main/package/qa/storages/Test11.java Tue Apr 29 19:11:53 2014
@@ -118,7 +118,7 @@ public class Test11 implements StorageTe
 			// check cloning at current state
 			// ==============================
 
 			// the new storage still was not commited so the clone must be empty
 			XStorage xClonedSubStorage = m_aTestHelper.cloneSubStorage( m_xStorageFactory, xTempStorage, "SubStorage1" );
 
 			if ( xClonedSubStorage == null )
@@ -139,7 +139,7 @@ public class Test11 implements StorageTe
 
 			if ( xClonedNameAccess.hasElements() )
 			{
-				m_aTestHelper.Error( "The new substorage still was not commited so it must be empty!" );
+				m_aTestHelper.Error( "The new substorage still was not committed so it must be empty!" );
 				return false;
 			}
 			
@@ -118,7 +118,7 @@ public class Test11 implements StorageTe
 			// ==============================
 
-			// the new storage still was not commited so the clone must be empty
+			// the new storage still was not committed so the clone must be empty
 			XStorage xClonedSubStorage = m_aTestHelper.cloneSubStorage( m_xStorageFactory, xTempStorage, "SubStorage1" );
 

Modified: openoffice/trunk/main/package/qa/storages/Test13.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/package/qa/storages/Test13.java?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================
--- openoffice/trunk/main/package/source/xstor/xstorage.cxx (original)
+++ openoffice/trunk/main/package/source/xstor/xstorage.cxx Tue Apr 29 19:11:53 2014
@@ -71,7 +71,7 @@ struct StorInternalData_Impl
 	::cppu::OMultiTypeInterfaceContainerHelper m_aListenersContainer; // list of listeners
 	::cppu::OTypeCollection* m_pTypeCollection;
 	sal_Bool m_bIsRoot;
-	sal_Int32 m_nStorageType; // the mode in wich the storage is used
+	sal_Int32 m_nStorageType; // the mode in which the storage is used
 	sal_Bool m_bReadOnlyWrap;
 
 	OChildDispListener_Impl* m_pSubElDispListener;
@@ -1062,7 +1062,7 @@ void OStorage_Impl::Commit()
 
 	// in case of a new empty storage it is possible that the contents are still not read
 	// ( the storage of course has no contents, but the initialization is postponed till the first use,
 	//   thus if a new storage was created and commited immediatelly it must be initialized here )
 	ReadContents();
 
 	// if storage is commited it should have a valid Package representation
@@ -1180,7 +1180,7 @@ void OStorage_Impl::Commit()
 			{
 				// the element must be just copied to the new temporary package folder
 				// the connection with the original package should not be lost just because
-				// the element is still refered by the folder in the original hierarchy
+				// the element is still referred by the folder in the original hierarchy
 				uno::Any aPackageElement = m_xPackageFolder->getByName( (*pElementIter)->m_aOriginalName );
 				xNewPackageFolder->insertByName( (*pElementIter)->m_aName, aPackageElement );
 			}
@@ -1545,7 +1545,7 @@ SotElement_Impl* OStorage_Impl::InsertEl
 			OSL_ENSURE( (*pElementIter)->m_bIsRemoved, "Try to insert an element instead of existing one!\n" );
 			if ( (*pElementIter)->m_bIsRemoved )
 			{
-				OSL_ENSURE( !(*pElementIter)->m_bIsInserted, "Inserted elements must be deleted immediatelly!\n" );
+				OSL_ENSURE( !(*pElementIter)->m_bIsInserted, "Inserted elements must be deleted immediately!\n" );
             	pDeletedElm = *pElementIter;
 				break;
 			}
@@ -1062,7 +1062,7 @@ void OStorage_Impl::Commit()
 	// in case of a new empty storage it is possible that the contents are still not read
 	// ( the storage of course has no contents, but the initialization is postponed till the first use,
-	//   thus if a new storage was created and commited immediatelly it must be initialized here )
+	//   thus if a new storage was created and commited immediately it must be initialized here )
 	ReadContents();
 

Modified: openoffice/trunk/main/package/source/xstor/xstorage.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/package/source/xstor/xstorage.hxx?rev=1591060&r1=1591059&r2=1591060&view=diff
==============================================================================